@@ -5,4 +5,7 @@ def multiply(a, b):
 def substract(a, b):
     return a - b
 def divide(a, b):
-    return a / b
\ No newline at end of file
+    return a / b
+
+def upgrade():
+    return "Version 0.0.2..."
\ No newline at end of file
